@@ -1,15 +1,44 @@
 package File::Find::Rule::DIZ;
 
+=head1 NAME
+
+File::Find::Rule::DIZ - Rule to match the contents of a FILE_ID.DIZ
+
+=head1 SYNOPSIS
+
+	use File::Find::Rule::DIZ;
+
+	my @files = find( diz => { text => qr/stuff and things/ }, in => '/archives' );
+
+=head1 DESCRIPTION
+
+This module will search through a ZIP archive, specifically the contents of the FILE_ID.DIZ
+file in the archive.
+
+=cut
+
 use strict;
+use warnings;
+
 use File::Find::Rule;
 use base qw( File::Find::Rule );
 use vars qw( @EXPORT $VERSION );
 
 @EXPORT  = @File::Find::Rule::EXPORT;
-$VERSION = '0.03';
+$VERSION = '0.04';
 
 use Archive::Zip;
 
+=head1 METHODS
+
+=head2 diz( %options )
+
+	my @files = find( diz => { text => qr/stuff and things/ }, in => '/archives' );
+
+For now, all you can do is search the text using a regex. Yehaw.
+
+=cut
+
 sub File::Find::Rule::diz {
 	my $self = shift->_force_object;
 
@@ -32,55 +61,37 @@ sub File::Find::Rule::diz {
 
 		# does it match the desired data?
 		my $diz = $member->contents;
-		return unless $diz =~ $criteria{text};
+		return unless $diz =~ $criteria{ text };
 
 		return 1;
 	} );
 }
 
-1;
+=head1 AUTHOR
 
-=pod
+=over 4 
 
-=head1 NAME
+=item * Brian Cassidy E<lt>bricas@cpan.orgE<gt>
 
-File::Find::Rule::DIZ - Rule to match the contents of a FILE_ID.DIZ
+=back
 
-=head1 SYNOPSIS
+=head1 COPYRIGHT AND LICENSE
 
-	use File::Find::Rule::DIZ;
+Copyright 2004 by Brian Cassidy
 
-	my @files = find( diz => { text => qr/stuff and things/ }, in => '/archives' );
-
-=head1 DESCRIPTION
-
-This module will search through a ZIP archive, specifically the contents of the FILE_ID.DIZ
-file in the archive.
-
-=head1 METHODS
-
-	my @files = find( diz => { text => qr/stuff and things/ }, in => '/archives' );
-
-For now, all you can do is search the text using a regex. Yehaw.
-
-=head1 BUGS
-
-If you have any questions, comments, bug reports or feature suggestions, 
-email them to Brian Cassidy <brian@alternation.net>.
-
-=head1 CREDITS
-
-This module was written by Brian Cassidy (http://www.alternation.net/). It borrows heavily
-from File::Find::Rule::MP3Info.
-
-=head1 LICENSE
-
-This program is free software; you can redistribute it and/or modify it under the terms
-of the Artistic License, distributed with Perl.
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself. 
 
 =head1 SEE ALSO
 
-	File::Find::Rule
-	File::Find::Rule::MP3Info
+=over 4 
 
-=cut
\ No newline at end of file
+=item * File::Find::Rule
+
+=item * File::Find::Rule::MP3Info
+
+=back
+
+=cut
+
+1;
\ No newline at end of file
